@@ -9,6 +9,8 @@
 # import sys
 # sys.setrecursionlimit(n)
 
+from lakefs_client.model.acl import ACL
+from lakefs_client.model.abort_presign_multipart_upload import AbortPresignMultipartUpload
 from lakefs_client.model.access_key_credentials import AccessKeyCredentials
 from lakefs_client.model.action_run import ActionRun
 from lakefs_client.model.action_run_list import ActionRunList
@@ -16,10 +18,14 @@ from lakefs_client.model.auth_capabilities import AuthCapabilities
 from lakefs_client.model.authentication_token import AuthenticationToken
 from lakefs_client.model.branch_creation import BranchCreation
 from lakefs_client.model.branch_protection_rule import BranchProtectionRule
+from lakefs_client.model.cherry_pick_creation import CherryPickCreation
 from lakefs_client.model.comm_prefs_input import CommPrefsInput
 from lakefs_client.model.commit import Commit
 from lakefs_client.model.commit_creation import CommitCreation
 from lakefs_client.model.commit_list import CommitList
+from lakefs_client.model.commit_record_creation import CommitRecordCreation
+from lakefs_client.model.complete_presign_multipart_upload import CompletePresignMultipartUpload
+from lakefs_client.model.config import Config
 from lakefs_client.model.credentials import Credentials
 from lakefs_client.model.credentials_list import CredentialsList
 from lakefs_client.model.credentials_with_secret import CredentialsWithSecret
@@ -27,10 +33,9 @@ from lakefs_client.model.current_user import CurrentUser
 from lakefs_client.model.diff import Diff
 from lakefs_client.model.diff_list import DiffList
 from lakefs_client.model.error import Error
+from lakefs_client.model.error_no_acl import ErrorNoACL
 from lakefs_client.model.find_merge_base_result import FindMergeBaseResult
-from lakefs_client.model.forgot_password_request import ForgotPasswordRequest
 from lakefs_client.model.garbage_collection_config import GarbageCollectionConfig
-from lakefs_client.model.garbage_collection_prepare_request import GarbageCollectionPrepareRequest
 from lakefs_client.model.garbage_collection_prepare_response import GarbageCollectionPrepareResponse
 from lakefs_client.model.garbage_collection_rule import GarbageCollectionRule
 from lakefs_client.model.garbage_collection_rules import GarbageCollectionRules
@@ -39,17 +44,19 @@ from lakefs_client.model.group_creation import GroupCreation
 from lakefs_client.model.group_list import GroupList
 from lakefs_client.model.hook_run import HookRun
 from lakefs_client.model.hook_run_list import HookRunList
-from lakefs_client.model.import_pagination import ImportPagination
-from lakefs_client.model.ingest_range_creation_response import IngestRangeCreationResponse
+from lakefs_client.model.import_creation import ImportCreation
+from lakefs_client.model.import_creation_response import ImportCreationResponse
+from lakefs_client.model.import_location import ImportLocation
+from lakefs_client.model.import_status import ImportStatus
+from lakefs_client.model.inline_object import InlineObject
 from lakefs_client.model.inline_object1 import InlineObject1
+from lakefs_client.model.installation_usage_report import InstallationUsageReport
 from lakefs_client.model.login_config import LoginConfig
 from lakefs_client.model.login_information import LoginInformation
 from lakefs_client.model.merge import Merge
 from lakefs_client.model.merge_result import MergeResult
-from lakefs_client.model.merge_result_summary import MergeResultSummary
 from lakefs_client.model.meta_range_creation import MetaRangeCreation
 from lakefs_client.model.meta_range_creation_response import MetaRangeCreationResponse
-from lakefs_client.model.next_step import NextStep
 from lakefs_client.model.object_copy_creation import ObjectCopyCreation
 from lakefs_client.model.object_error import ObjectError
 from lakefs_client.model.object_error_list import ObjectErrorList
@@ -57,26 +64,30 @@ from lakefs_client.model.object_stage_creation import ObjectStageCreation
 from lakefs_client.model.object_stats import ObjectStats
 from lakefs_client.model.object_stats_list import ObjectStatsList
 from lakefs_client.model.object_user_metadata import ObjectUserMetadata
-from lakefs_client.model.otf_diff_entry import OtfDiffEntry
-from lakefs_client.model.otf_diff_list import OtfDiffList
 from lakefs_client.model.pagination import Pagination
 from lakefs_client.model.path_list import PathList
 from lakefs_client.model.policy import Policy
 from lakefs_client.model.policy_list import PolicyList
 from lakefs_client.model.prepare_gc_uncommitted_request import PrepareGCUncommittedRequest
 from lakefs_client.model.prepare_gc_uncommitted_response import PrepareGCUncommittedResponse
+from lakefs_client.model.presign_multipart_upload import PresignMultipartUpload
 from lakefs_client.model.range_metadata import RangeMetadata
 from lakefs_client.model.ref import Ref
 from lakefs_client.model.ref_list import RefList
 from lakefs_client.model.refs_dump import RefsDump
+from lakefs_client.model.refs_restore import RefsRestore
 from lakefs_client.model.repository import Repository
 from lakefs_client.model.repository_creation import RepositoryCreation
+from lakefs_client.model.repository_dump_status import RepositoryDumpStatus
 from lakefs_client.model.repository_list import RepositoryList
+from lakefs_client.model.repository_metadata import RepositoryMetadata
+from lakefs_client.model.repository_metadata_keys import RepositoryMetadataKeys
+from lakefs_client.model.repository_metadata_set import RepositoryMetadataSet
+from lakefs_client.model.repository_restore_status import RepositoryRestoreStatus
 from lakefs_client.model.reset_creation import ResetCreation
 from lakefs_client.model.revert_creation import RevertCreation
 from lakefs_client.model.setup import Setup
 from lakefs_client.model.setup_state import SetupState
-from lakefs_client.model.stage_range_creation import StageRangeCreation
 from lakefs_client.model.staging_location import StagingLocation
 from lakefs_client.model.staging_metadata import StagingMetadata
 from lakefs_client.model.statement import Statement
@@ -85,8 +96,11 @@ from lakefs_client.model.stats_events_list import StatsEventsList
 from lakefs_client.model.storage_config import StorageConfig
 from lakefs_client.model.storage_uri import StorageURI
 from lakefs_client.model.tag_creation import TagCreation
+from lakefs_client.model.task_info import TaskInfo
 from lakefs_client.model.underlying_object_properties import UnderlyingObjectProperties
-from lakefs_client.model.update_password_by_token import UpdatePasswordByToken
+from lakefs_client.model.update_token import UpdateToken
+from lakefs_client.model.upload_part import UploadPart
+from lakefs_client.model.usage_report import UsageReport
 from lakefs_client.model.user import User
 from lakefs_client.model.user_creation import UserCreation
 from lakefs_client.model.user_list import UserList
